@@ -33,7 +33,7 @@ class ACEEncoding(): #{{{1
         encoding = 'CP1252'
 
         if '.' in norm_locale:
-            encoding = norm_locale.split(',')[1]
+            encoding = norm_locale.split('.')[1]
         elif '_' in strng:
             encoding = self._findNormalisedForm(strng.split('_')[1])
 
