@@ -2,9 +2,9 @@
 
 import errno
 import exceptions
-import locale
+import gconf
 import sys
-import struct
+import time
 
 from PyQt4.QtCore import QCoreApplication, QDir, QFile, QIODevice, QString, \
                          QStringList, QTextCodec
@@ -24,6 +24,8 @@ sizes = {
     'header': 8,
     'dictHeader': 8
 }
+gconf_root = '/apps/osso/inputmethod/hildon-im-languages'
+gconf_entry = 'word-completion'
 
 class ACEFileReadException(Exception): #{{{1
     def __init__(self, msg, language, entry = None):
@@ -45,6 +47,29 @@ class ACEFile(): #{{{1
 
     def __init__(self): #{{{2
         self._encoding = ACEEncoding()
+        self._gconf = gconf.client_get_default()
+
+    def _autocomplete_set(self, flag): #{{{2
+        if flag == 0:
+            cs = gconf.ChangeSet()
+            rev_cs = gconf.ChangeSet()
+
+            for i in self._gconf.all_dirs(gconf_root):
+                entry = '%s/%s' % (i, gconf_entry)
+                val = self._gconf.get_bool(entry)
+
+                if val == 1:
+                    cs.set_bool(entry, 0)
+                    rev_cs.set_bool(entry, 1)
+
+            if cs.size > 0:
+                self._gconf.commit_change_set(cs, True)
+                time.sleep(1)
+
+            self._gconf_cs = rev_cs
+        else:
+            if self._gconf_cs.size() > 0:
+                self._gconf.commit_change_set(self._gconf_cs, True)
 
     def _calculateDataSize(self): #{{{2
         size = sizes['header']
@@ -172,8 +197,13 @@ class ACEFile(): #{{{1
         if not file.exists():
             raise IOError(errno.ENOENT, "File not found", dictionaryFile)
 
-        if not file.open(QIODevice.ReadOnly):
-            raise IOError(errno.EIO, "Cannot open file", dictionaryFile)
+        self._autocomplete_set(0)
+
+        try:
+            if not file.open(QIODevice.ReadOnly):
+                raise IOError(errno.EIO, "Cannot open file", dictionaryFile)
+        finally:
+            self._autocomplete_set(1)
 
         (paddingOffset, dictionaryCount) = self._readHeader(file)
         i = 1
@@ -215,10 +245,13 @@ class ACEFile(): #{{{1
         if not QFile.rename(dictionaryFile, "%s.bak" % dictionaryFile):
             raise IOError(errno.EIO, "Error writing backup file", "%s.bak" % dictionaryFile)
 
-        if not QFile.rename("%s.tmp" % dictionaryFile, dictionaryFile):
-            raise IOError(errno.EIO, "Error replacing dictionary", dictionaryFile)
+        self._autocomplete_set(0)
 
-        call(['/usr/bin/killall', 'hildon-input-method'])
+        try:
+            if not QFile.rename("%s.tmp" % dictionaryFile, dictionaryFile):
+                raise IOError(errno.EIO, "Error replacing dictionary", dictionaryFile)
+        finally:
+            self._autocomplete_set(1)
 
     def getLanguages(self): #{{{2
         return self._dicts.keys()
